[gcompris/gcomprixogoo] Added basic instructions to compile GCompris on MacOSX.



commit dff02f13daf93ff44fdff8957820987813347df0
Author: Bruno Coudoin <bruno coudoin gcompris net>
Date:   Tue Aug 3 19:09:25 2010 +0200

    Added basic instructions to compile GCompris on MacOSX.

 README.macosx          |   24 ++++++++++++++++++++++++
 macosx/createBundle.sh |    4 ++--
 2 files changed, 26 insertions(+), 2 deletions(-)
---
diff --git a/README.macosx b/README.macosx
new file mode 100644
index 0000000..3ebdce2
--- /dev/null
+++ b/README.macosx
@@ -0,0 +1,24 @@
+These are the instructions to build GCompris on MacOSX.
+
+Requirements:
+MacOSX 10.4 or above.
+
+First, create your compilation environment following the instructions here:
+http://gtk-osx.sourceforge.net/
+
+Configure step:
+  cd macosx
+  ./configure_mac.sh
+
+At this point, you will have missing dependencies that you must download
+and install manually following the rules defined by gtk-osx.
+
+Compilation step:
+  make
+
+Bundle step:
+  make install
+  ./createBundle.sh
+
+The resulting file is GCompris.dmg
+
diff --git a/macosx/createBundle.sh b/macosx/createBundle.sh
index 40c9772..aa3d81a 100755
--- a/macosx/createBundle.sh
+++ b/macosx/createBundle.sh
@@ -13,8 +13,8 @@ cd GCompris
 ln -s /Applications .
 cd -
 
-# Create the bundle of the complete application
-echo "Create the bundle of the complete application"
+# Create the bundle of the whole application
+echo "Create the bundle of the whole application"
 ige-mac-bundler gcompris.bundle
 
 # Create the distributable .dmg



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]